@@ -9,6 +9,7 @@ _errors = {}
 from . import xproto
 from . import render
 class BadOutputError(xcffib.Error):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -24,6 +25,7 @@ class BadOutputError(xcffib.Error):
 BadBadOutput = BadOutputError
 _errors[0] = BadOutputError
 class BadCrtcError(xcffib.Error):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -39,6 +41,7 @@ class BadCrtcError(xcffib.Error):
 BadBadCrtc = BadCrtcError
 _errors[1] = BadCrtcError
 class BadModeError(xcffib.Error):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -54,6 +57,7 @@ class BadModeError(xcffib.Error):
 BadBadMode = BadModeError
 _errors[2] = BadModeError
 class BadProviderError(xcffib.Error):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -76,6 +80,7 @@ class Rotation:
     Reflect_X = 1 << 4
     Reflect_Y = 1 << 5
 class ScreenSize(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -97,6 +102,7 @@ class ScreenSize(xcffib.Struct):
         self.mheight = mheight
         return self
 class RefreshRates(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -117,6 +123,7 @@ class RefreshRates(xcffib.Struct):
         self.rates = rates
         return self
 class QueryVersionReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -132,6 +139,7 @@ class SetConfig:
     InvalidTime = 2
     Failed = 3
 class SetScreenConfigReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -151,6 +159,7 @@ class NotifyMask:
     ResourceChange = 1 << 6
     Lease = 1 << 7
 class GetScreenInfoReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -164,6 +173,7 @@ class GetScreenInfoReply(xcffib.Reply):
 class GetScreenInfoCookie(xcffib.Cookie):
     reply_type = GetScreenInfoReply
 class GetScreenSizeRangeReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -189,6 +199,7 @@ class ModeFlag:
     DoubleClock = 1 << 12
     HalveClock = 1 << 13
 class ModeInfo(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -219,6 +230,7 @@ class ModeInfo(xcffib.Struct):
         self.mode_flags = mode_flags
         return self
 class GetScreenResourcesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -240,6 +252,7 @@ class Connection:
     Disconnected = 1
     Unknown = 2
 class GetOutputInfoReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -257,6 +270,7 @@ class GetOutputInfoReply(xcffib.Reply):
 class GetOutputInfoCookie(xcffib.Cookie):
     reply_type = GetOutputInfoReply
 class ListOutputPropertiesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -268,6 +282,7 @@ class ListOutputPropertiesReply(xcffib.Reply):
 class ListOutputPropertiesCookie(xcffib.Cookie):
     reply_type = ListOutputPropertiesReply
 class QueryOutputPropertyReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -279,6 +294,7 @@ class QueryOutputPropertyReply(xcffib.Reply):
 class QueryOutputPropertyCookie(xcffib.Cookie):
     reply_type = QueryOutputPropertyReply
 class GetOutputPropertyReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -290,6 +306,7 @@ class GetOutputPropertyReply(xcffib.Reply):
 class GetOutputPropertyCookie(xcffib.Cookie):
     reply_type = GetOutputPropertyReply
 class CreateModeReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -300,6 +317,7 @@ class CreateModeReply(xcffib.Reply):
 class CreateModeCookie(xcffib.Cookie):
     reply_type = CreateModeReply
 class GetCrtcInfoReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -313,6 +331,7 @@ class GetCrtcInfoReply(xcffib.Reply):
 class GetCrtcInfoCookie(xcffib.Cookie):
     reply_type = GetCrtcInfoReply
 class SetCrtcConfigReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -323,6 +342,7 @@ class SetCrtcConfigReply(xcffib.Reply):
 class SetCrtcConfigCookie(xcffib.Cookie):
     reply_type = SetCrtcConfigReply
 class GetCrtcGammaSizeReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -333,6 +353,7 @@ class GetCrtcGammaSizeReply(xcffib.Reply):
 class GetCrtcGammaSizeCookie(xcffib.Cookie):
     reply_type = GetCrtcGammaSizeReply
 class GetCrtcGammaReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -348,6 +369,7 @@ class GetCrtcGammaReply(xcffib.Reply):
 class GetCrtcGammaCookie(xcffib.Cookie):
     reply_type = GetCrtcGammaReply
 class GetScreenResourcesCurrentReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -370,6 +392,7 @@ class Transform:
     ScaleDown = 1 << 2
     Projective = 1 << 3
 class GetPanningReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -380,6 +403,7 @@ class GetPanningReply(xcffib.Reply):
 class GetPanningCookie(xcffib.Cookie):
     reply_type = GetPanningReply
 class SetPanningReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -390,6 +414,7 @@ class SetPanningReply(xcffib.Reply):
 class SetPanningCookie(xcffib.Cookie):
     reply_type = SetPanningReply
 class GetOutputPrimaryReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -400,6 +425,7 @@ class GetOutputPrimaryReply(xcffib.Reply):
 class GetOutputPrimaryCookie(xcffib.Cookie):
     reply_type = GetOutputPrimaryReply
 class GetProvidersReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -416,6 +442,7 @@ class ProviderCapability:
     SourceOffload = 1 << 2
     SinkOffload = 1 << 3
 class GetProviderInfoReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -435,6 +462,7 @@ class GetProviderInfoReply(xcffib.Reply):
 class GetProviderInfoCookie(xcffib.Cookie):
     reply_type = GetProviderInfoReply
 class ListProviderPropertiesReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -446,6 +474,7 @@ class ListProviderPropertiesReply(xcffib.Reply):
 class ListProviderPropertiesCookie(xcffib.Cookie):
     reply_type = ListProviderPropertiesReply
 class QueryProviderPropertyReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -457,6 +486,7 @@ class QueryProviderPropertyReply(xcffib.Reply):
 class QueryProviderPropertyCookie(xcffib.Cookie):
     reply_type = QueryProviderPropertyReply
 class GetProviderPropertyReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -468,6 +498,7 @@ class GetProviderPropertyReply(xcffib.Reply):
 class GetProviderPropertyCookie(xcffib.Cookie):
     reply_type = GetProviderPropertyReply
 class ScreenChangeNotifyEvent(xcffib.Event):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -508,6 +539,7 @@ class Notify:
     ResourceChange = 5
     Lease = 6
 class CrtcChange(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -534,6 +566,7 @@ class CrtcChange(xcffib.Struct):
         self.height = height
         return self
 class OutputChange(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -560,6 +593,7 @@ class OutputChange(xcffib.Struct):
         self.subpixel_order = subpixel_order
         return self
 class OutputProperty(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -582,6 +616,7 @@ class OutputProperty(xcffib.Struct):
         self.status = status
         return self
 class ProviderChange(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -602,6 +637,7 @@ class ProviderChange(xcffib.Struct):
         self.provider = provider
         return self
 class ProviderProperty(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -624,6 +660,7 @@ class ProviderProperty(xcffib.Struct):
         self.state = state
         return self
 class ResourceChange(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -643,6 +680,7 @@ class ResourceChange(xcffib.Struct):
         self.window = window
         return self
 class MonitorInfo(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -672,6 +710,7 @@ class MonitorInfo(xcffib.Struct):
         self.outputs = outputs
         return self
 class GetMonitorsReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -683,6 +722,7 @@ class GetMonitorsReply(xcffib.Reply):
 class GetMonitorsCookie(xcffib.Cookie):
     reply_type = GetMonitorsReply
 class CreateLeaseReply(xcffib.Reply):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -693,6 +733,7 @@ class CreateLeaseReply(xcffib.Reply):
 class CreateLeaseCookie(xcffib.Cookie):
     reply_type = CreateLeaseReply
 class LeaseNotify(xcffib.Struct):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -714,6 +755,7 @@ class LeaseNotify(xcffib.Struct):
         self.created = created
         return self
 class NotifyData(xcffib.Union):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -730,6 +772,7 @@ class NotifyData(xcffib.Union):
         buf.write(self.cc.pack() if hasattr(self.cc, "pack") else CrtcChange.synthetic(*self.cc).pack())
         return buf.getvalue()
 class NotifyEvent(xcffib.Event):
+    xge = False
     def __init__(self, unpacker):
         if isinstance(unpacker, xcffib.Protobj):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
@@ -862,7 +905,7 @@ class randrExtension(xcffib.Extension):
     def SetCrtcTransform(self, crtc, transform, filter_len, filter_name, filter_params_len, filter_params, is_checked=False):
         buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", crtc))
-        buf.write(transform.pack() if hasattr(transform, "pack") else TRANSFORM.synthetic(*transform).pack())
+        buf.write(transform.pack() if hasattr(transform, "pack") else render.TRANSFORM.synthetic(*transform).pack())
         buf.write(struct.pack("=H", filter_len))
         buf.write(struct.pack("=2x", ))
         buf.write(xcffib.pack_list(filter_name, "c"))
